oc\_ocdm.metadata.entities package
==================================

Modules
-------
.. toctree::
   :maxdepth: 1

   entities/oc_ocdm.metadata.entities.dataset
   entities/oc_ocdm.metadata.entities.distribution
